ace.define("ace/theme/xcode",["require","exports","module","ace/lib/dom"],function(a,b,c){b.isDark=!1,b.cssClass="ace-xcode",b.cssText="/* THIS THEME WAS AUTOGENERATED BY Theme.tmpl.css (UUID: EE3AD170-2B7F-4DE1-B724-C75F13FE0085) */.ace-xcode .ace_editor {  border: 2px solid rgb(159, 159, 159)}.ace-xcode .ace_editor.ace_focus {  border: 2px solid #327fbd}.ace-xcode .ace_gutter {  background: #e8e8e8;  color: #333}.ace-xcode .ace_print_margin {  width: 1px;  background: #e8e8e8}.ace-xcode .ace_scroller {  background-color: #FFFFFF}.ace-xcode .ace_text-layer {  color: #000000}.ace-xcode .ace_cursor {  border-left: 2px solid #000000}.ace-xcode .ace_cursor.ace_overwrite {  border-left: 0px;  border-bottom: 1px solid #000000}.ace-xcode .ace_marker-layer .ace_selection {  background: #B5D5FF}.ace-xcode.multiselect .ace_selection.start {  box-shadow: 0 0 3px 0px #FFFFFF;  border-radius: 2px}.ace-xcode .ace_marker-layer .ace_step {  background: rgb(198, 219, 174)}.ace-xcode .ace_marker-layer .ace_bracket {  margin: -1px 0 0 -1px;  border: 1px solid #BFBFBF}.ace-xcode .ace_marker-layer .ace_active_line {  background: rgba(0, 0, 0, 0.071)}.ace-xcode .ace_gutter_active_line {  background-color: rgba(0, 0, 0, 0.071)}.ace-xcode .ace_marker-layer .ace_selected_word {  border: 1px solid #B5D5FF}.ace-xcode .ace_constant.ace_language,.ace-xcode .ace_keyword,.ace-xcode .ace_meta,.ace-xcode .ace_variable.ace_language {  color: #C800A4}.ace-xcode .ace_invisible {  color: #BFBFBF}.ace-xcode .ace_constant.ace_character,.ace-xcode .ace_constant.ace_other {  color: #275A5E}.ace-xcode .ace_constant.ace_numeric {  color: #3A00DC}.ace-xcode .ace_entity.ace_other.ace_attribute-name,.ace-xcode .ace_support.ace_constant,.ace-xcode .ace_support.ace_function {  color: #450084}.ace-xcode .ace_fold {  background-color: #C800A4;  border-color: #000000}.ace-xcode .ace_entity.ace_name.ace_tag,.ace-xcode .ace_support.ace_class,.ace-xcode .ace_support.ace_type {  color: #790EAD}.ace-xcode .ace_storage {  color: #C900A4}.ace-xcode .ace_string {  color: #DF0002}.ace-xcode .ace_comment {  color: #008E00}.ace-xcode .ace_indent-guide {  background: url(data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAEAAAACCAYAAACZgbYnAAAAE0lEQVQImWP4////f4bLly//BwAmVgd1/w11/gAAAABJRU5ErkJggg==) right repeat-y;}";var d=a("../lib/dom");d.importCssString(b.cssText,b.cssClass)})