ace.define("ace/theme/solarized_dark",["require","exports","module","ace/lib/dom"],function(a,b,c){b.isDark=!0,b.cssClass="ace-solarized-dark",b.cssText=".ace-solarized-dark .ace_editor {  border: 2px solid rgb(159, 159, 159)}.ace-solarized-dark .ace_editor.ace_focus {  border: 2px solid #327fbd}.ace-solarized-dark .ace_gutter {  background: #01313f;  color: #d0edf7}.ace-solarized-dark .ace_print_margin {  width: 1px;  background: #33555E}.ace-solarized-dark .ace_scroller {  background-color: #002B36}.ace-solarized-dark .ace_entity.ace_other.ace_attribute-name,.ace-solarized-dark .ace_storage,.ace-solarized-dark .ace_text-layer {  color: #93A1A1}.ace-solarized-dark .ace_cursor {  border-left: 2px solid #D30102}.ace-solarized-dark .ace_cursor.ace_overwrite {  border-left: 0px;  border-bottom: 1px solid #D30102}.ace-solarized-dark .ace_marker-layer .ace_active_line,.ace-solarized-dark .ace_marker-layer .ace_selection {  background: rgba(255, 255, 255, 0.1)}.ace-solarized-dark.multiselect .ace_selection.start {  box-shadow: 0 0 3px 0px #002B36;  border-radius: 2px}.ace-solarized-dark .ace_marker-layer .ace_step {  background: rgb(102, 82, 0)}.ace-solarized-dark .ace_marker-layer .ace_bracket {  margin: -1px 0 0 -1px;  border: 1px solid rgba(147, 161, 161, 0.50)}.ace-solarized-dark .ace_gutter_active_line {  background-color: #0d3440}.ace-solarized-dark .ace_marker-layer .ace_selected_word {  border: 1px solid #073642}.ace-solarized-dark .ace_invisible {  color: rgba(147, 161, 161, 0.50)}.ace-solarized-dark .ace_keyword,.ace-solarized-dark .ace_meta,.ace-solarized-dark .ace_support.ace_class,.ace-solarized-dark .ace_support.ace_type {  color: #859900}.ace-solarized-dark .ace_constant.ace_character,.ace-solarized-dark .ace_constant.ace_other {  color: #CB4B16}.ace-solarized-dark .ace_constant.ace_language {  color: #B58900}.ace-solarized-dark .ace_constant.ace_numeric {  color: #D33682}.ace-solarized-dark .ace_fold {  background-color: #268BD2;  border-color: #93A1A1}.ace-solarized-dark .ace_entity.ace_name.ace_function,.ace-solarized-dark .ace_entity.ace_name.ace_tag,.ace-solarized-dark .ace_support.ace_function,.ace-solarized-dark .ace_variable,.ace-solarized-dark .ace_variable.ace_language {  color: #268BD2}.ace-solarized-dark .ace_string {  color: #2AA198}.ace-solarized-dark .ace_string.ace_regexp {  color: #D30102}.ace-solarized-dark .ace_comment {  font-style: italic;  color: #657B83}.ace-solarized-dark .ace_markup.ace_underline {  text-decoration: underline}.ace-solarized-dark .ace_indent-guide {  background: url(data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAEAAAACCAYAAACZgbYnAAAAEklEQVQImWNg0Db7zzBz5sz/AA82BCv7wOIDAAAAAElFTkSuQmCC) right repeat-y}";var d=a("../lib/dom");d.importCssString(b.cssText,b.cssClass)})